<?php
/**
 * @license
 * Copyright 2018 TruongLuu. All Rights Reserved.
 */

namespace Truonglv\StickyTimer;

use XF\Mvc\Entity\Entity;
use Truonglv\StickyTimer\Entity\Sticky;

class Listener
{
    public static $timeUnits = [
        'hours' => 3600,
        'days' => 86400,
        'weeks' => 604800,
        'months' => 2592000
    ];

    public static function onThreadStructure(\XF\Mvc\Entity\Manager $em, \XF\Mvc\Entity\Structure &$structure)
    {
        $structure->relations['StickyTimer'] = [
            'type' => Entity::TO_ONE,
            'entity' => 'Truonglv\StickyTimer:Sticky',
            'conditions' => 'thread_id',
            'primary' => true
        ];
    }

    public static function onThreadPostSave(Entity $entity)
    {
        if (!$entity->isUpdate()) {
            return;
        }

        if ($entity->isChanged('sticky')
            && !$entity->getValue('sticky')
        ) {
            self::deleteSticky($entity);
        }
    }

    public static function onThreadPostDelete(Entity $entity)
    {
        self::deleteSticky($entity);
    }

    public static function isEnableNode($nodeId)
    {
        $allowed = in_array($nodeId, \XF::options()->tl_StickyTimer_applyNodes);
        if (func_num_args() === 3 && !$allowed) {
            return null;
        }

        return $allowed;
    }

    protected static function deleteSticky(Entity $entity)
    {
        /** @var Sticky|null $sticky */
        $sticky = $entity->getRelation('StickyTimer');

        if ($sticky) {
            $sticky->setOption('remove_sticky', false);
            $sticky->delete();
        }
    }
}
